# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FabricArgs', 'Fabric']

@pulumi.input_type
class FabricArgs:
    def __init__(__self__, *,
                 recovery_vault_name: pulumi.Input[_builtins.str],
                 resource_group_name: pulumi.Input[_builtins.str],
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Fabric resource.

        :param pulumi.Input[_builtins.str] recovery_vault_name: The name of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: In what region should the fabric be located. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name of the network mapping. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "recovery_vault_name", recovery_vault_name)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="recoveryVaultName")
    def recovery_vault_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_name")

    @recovery_vault_name.setter
    def recovery_vault_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "recovery_vault_name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        In what region should the fabric be located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network mapping. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FabricState:
    def __init__(__self__, *,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_vault_name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Fabric resources.

        :param pulumi.Input[_builtins.str] location: In what region should the fabric be located. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name of the network mapping. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] recovery_vault_name: The name of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if recovery_vault_name is not None:
            pulumi.set(__self__, "recovery_vault_name", recovery_vault_name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        In what region should the fabric be located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network mapping. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="recoveryVaultName")
    def recovery_vault_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_name")

    @recovery_vault_name.setter
    def recovery_vault_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recovery_vault_name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)


@pulumi.type_token("azure:siterecovery/fabric:Fabric")
class Fabric(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_vault_name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Azure Site Recovery Replication Fabric within a Recovery Services vault. Only Azure fabrics are supported at this time. Replication Fabrics serve as a container within an Azure region for other Site Recovery resources such as protection containers, protected items, network mappings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        primary = azure.core.ResourceGroup("primary",
            name="tfex-network-mapping-primary",
            location="West US")
        secondary = azure.core.ResourceGroup("secondary",
            name="tfex-network-mapping-secondary",
            location="East US")
        vault = azure.recoveryservices.Vault("vault",
            name="example-recovery-vault",
            location=secondary.location,
            resource_group_name=secondary.name,
            sku="Standard")
        fabric = azure.siterecovery.Fabric("fabric",
            name="primary-fabric",
            resource_group_name=secondary.name,
            recovery_vault_name=vault.name,
            location=primary.location)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.RecoveryServices` - 2024-04-01

        ## Import

        Site Recovery Fabric can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/fabric:Fabric myfabric /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationFabrics/fabric-name
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] location: In what region should the fabric be located. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name of the network mapping. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] recovery_vault_name: The name of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FabricArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Azure Site Recovery Replication Fabric within a Recovery Services vault. Only Azure fabrics are supported at this time. Replication Fabrics serve as a container within an Azure region for other Site Recovery resources such as protection containers, protected items, network mappings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        primary = azure.core.ResourceGroup("primary",
            name="tfex-network-mapping-primary",
            location="West US")
        secondary = azure.core.ResourceGroup("secondary",
            name="tfex-network-mapping-secondary",
            location="East US")
        vault = azure.recoveryservices.Vault("vault",
            name="example-recovery-vault",
            location=secondary.location,
            resource_group_name=secondary.name,
            sku="Standard")
        fabric = azure.siterecovery.Fabric("fabric",
            name="primary-fabric",
            resource_group_name=secondary.name,
            recovery_vault_name=vault.name,
            location=primary.location)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.RecoveryServices` - 2024-04-01

        ## Import

        Site Recovery Fabric can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/fabric:Fabric myfabric /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationFabrics/fabric-name
        ```


        :param str resource_name: The name of the resource.
        :param FabricArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FabricArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_vault_name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FabricArgs.__new__(FabricArgs)

            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if recovery_vault_name is None and not opts.urn:
                raise TypeError("Missing required property 'recovery_vault_name'")
            __props__.__dict__["recovery_vault_name"] = recovery_vault_name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
        super(Fabric, __self__).__init__(
            'azure:siterecovery/fabric:Fabric',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            recovery_vault_name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'Fabric':
        """
        Get an existing Fabric resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] location: In what region should the fabric be located. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name of the network mapping. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] recovery_vault_name: The name of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FabricState.__new__(_FabricState)

        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["recovery_vault_name"] = recovery_vault_name
        __props__.__dict__["resource_group_name"] = resource_group_name
        return Fabric(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        In what region should the fabric be located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the network mapping. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="recoveryVaultName")
    def recovery_vault_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource group where the vault that should be updated is located. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PortalDashboardArgs', 'PortalDashboard']

@pulumi.input_type
class PortalDashboardArgs:
    def __init__(__self__, *,
                 dashboard_properties: pulumi.Input[_builtins.str],
                 resource_group_name: pulumi.Input[_builtins.str],
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a PortalDashboard resource.

        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "dashboard_properties", dashboard_properties)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> pulumi.Input[_builtins.str]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @dashboard_properties.setter
    def dashboard_properties(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "dashboard_properties", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PortalDashboardState:
    def __init__(__self__, *,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering PortalDashboard resources.

        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        if dashboard_properties is not None:
            pulumi.set(__self__, "dashboard_properties", dashboard_properties)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @dashboard_properties.setter
    def dashboard_properties(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dashboard_properties", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:portal/portalDashboard:PortalDashboard")
class PortalDashboard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a shared dashboard in the Azure Portal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        config = pulumi.Config()
        # Content for the MD tile
        md_content = config.get("mdContent")
        if md_content is None:
            md_content = "# Hello all :)"
        # Link to a video
        video_link = config.get("videoLink")
        if video_link is None:
            video_link = "https://www.youtube.com/watch?v=......"
        current = azure.core.get_subscription()
        example = azure.core.ResourceGroup("example",
            name="mygroup",
            location="West Europe")
        my_board = azure.portal.PortalDashboard("my-board",
            name="my-cool-dashboard",
            resource_group_name=example.name,
            location=example.location,
            tags={
                "source": "terraform",
            },
            dashboard_properties=f\"\"\"{{
           \\"lenses\\": {{
                \\"0\\": {{
                    \\"order\\": 0,
                    \\"parts\\": {{
                        \\"0\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 0,
                                \\"rowSpan\\": 2,
                                \\"colSpan\\": 3
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/MarkdownPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"content\\": \\"{md_content}\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"title\\": \\"\\"
                                        }}
                                    }}
                                }}
                            }}
                        }},               
                        \\"1\\": {{
                            \\"position\\": {{
                                \\"x\\": 5,
                                \\"y\\": 0,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/VideoPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"title\\": \\"Important Information\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"src\\": \\"{video_link}\\",
                                            \\"autoplay\\": true
                                        }}
                                    }}
                                }}
                            }}
                        }},
                        \\"2\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 4,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [
                                    {{
                                        \\"name\\": \\"ComponentId\\",
                                        \\"value\\": \\"/subscriptions/{current.subscription_id}/resourceGroups/myRG/providers/microsoft.insights/components/myWebApp\\"
                                    }}
                                ],
                                \\"type\\": \\"Extension/AppInsightsExtension/PartType/AppMapGalPt\\",
                                \\"settings\\": {{}},
                                \\"asset\\": {{
                                    \\"idInputName\\": \\"ComponentId\\",
                                    \\"type\\": \\"ApplicationInsights\\"
                                }}
                            }}
                        }}              
                    }}
                }}
            }},
            \\"metadata\\": {{
                \\"model\\": {{
                    \\"timeRange\\": {{
                        \\"value\\": {{
                            \\"relative\\": {{
                                \\"duration\\": 24,
                                \\"timeUnit\\": 1
                            }}
                        }},
                        \\"type\\": \\"MsPortalFx.Composition.Configuration.ValueTypes.TimeRange\\"
                    }},
                    \\"filterLocale\\": {{
                        \\"value\\": \\"en-us\\"
                    }},
                    \\"filters\\": {{
                        \\"value\\": {{
                            \\"MsPortalFx_TimeRange\\": {{
                                \\"model\\": {{
                                    \\"format\\": \\"utc\\",
                                    \\"granularity\\": \\"auto\\",
                                    \\"relative\\": \\"24h\\"
                                }},
                                \\"displayCache\\": {{
                                    \\"name\\": \\"UTC Time\\",
                                    \\"value\\": \\"Past 24 hours\\"
                                }},
                                \\"filteredPartIds\\": [
                                    \\"StartboardPart-UnboundPart-ae44fef5-76b8-46b0-86f0-2b3f47bad1c7\\"
                                ]
                            }}
                        }}
                    }}
                }}
            }}
        }}
        \"\"\")
        ```

        It is recommended to follow the steps outlined
        [here](https://docs.microsoft.com/azure/azure-portal/azure-portal-dashboards-create-programmatically#fetch-the-json-representation-of-the-dashboard) to create a Dashboard in the Portal and extract the relevant JSON to use in this resource. From the extracted JSON, the contents of the `properties: {}` object can used. Variables can be injected as needed - see above example.

        ### Using a `template_file` data source or the `templatefile` function

        Since the contents of the dashboard JSON can be quite lengthy, use a template file to improve readability:

        `dash.tpl`:

        This is then referenced in the `.tf` file by using a `template_file` data source (terraform 0.11 or earlier), or the `templatefile` function (terraform 0.12+).

        `main.tf` (terraform 0.11 or earlier):

        ```python
        import pulumi
        import pulumi_azurerm as azurerm


        def not_implemented(msg):
            raise NotImplementedError(msg)

        dash_template = not_implemented("The template_file data resource is not yet supported.")
        #...
        my_board = azurerm.index.Dashboard("my-board",
            name=my-cool-dashboard,
            resource_group_name=example.name,
            location=example.location,
            tags={
                source: terraform,
            },
            dashboard_properties=dash_template.rendered)
        ```

        `main.tf` (terraform 0.12+)

        ## Import

        Dashboards can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:portal/portalDashboard:PortalDashboard my-board /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Portal/dashboards/00000000-0000-0000-0000-000000000000
        ```

        Note the URI in the above sample can be found using the Resource Explorer tool in the Azure Portal.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PortalDashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a shared dashboard in the Azure Portal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        config = pulumi.Config()
        # Content for the MD tile
        md_content = config.get("mdContent")
        if md_content is None:
            md_content = "# Hello all :)"
        # Link to a video
        video_link = config.get("videoLink")
        if video_link is None:
            video_link = "https://www.youtube.com/watch?v=......"
        current = azure.core.get_subscription()
        example = azure.core.ResourceGroup("example",
            name="mygroup",
            location="West Europe")
        my_board = azure.portal.PortalDashboard("my-board",
            name="my-cool-dashboard",
            resource_group_name=example.name,
            location=example.location,
            tags={
                "source": "terraform",
            },
            dashboard_properties=f\"\"\"{{
           \\"lenses\\": {{
                \\"0\\": {{
                    \\"order\\": 0,
                    \\"parts\\": {{
                        \\"0\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 0,
                                \\"rowSpan\\": 2,
                                \\"colSpan\\": 3
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/MarkdownPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"content\\": \\"{md_content}\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"title\\": \\"\\"
                                        }}
                                    }}
                                }}
                            }}
                        }},               
                        \\"1\\": {{
                            \\"position\\": {{
                                \\"x\\": 5,
                                \\"y\\": 0,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/VideoPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"title\\": \\"Important Information\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"src\\": \\"{video_link}\\",
                                            \\"autoplay\\": true
                                        }}
                                    }}
                                }}
                            }}
                        }},
                        \\"2\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 4,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [
                                    {{
                                        \\"name\\": \\"ComponentId\\",
                                        \\"value\\": \\"/subscriptions/{current.subscription_id}/resourceGroups/myRG/providers/microsoft.insights/components/myWebApp\\"
                                    }}
                                ],
                                \\"type\\": \\"Extension/AppInsightsExtension/PartType/AppMapGalPt\\",
                                \\"settings\\": {{}},
                                \\"asset\\": {{
                                    \\"idInputName\\": \\"ComponentId\\",
                                    \\"type\\": \\"ApplicationInsights\\"
                                }}
                            }}
                        }}              
                    }}
                }}
            }},
            \\"metadata\\": {{
                \\"model\\": {{
                    \\"timeRange\\": {{
                        \\"value\\": {{
                            \\"relative\\": {{
                                \\"duration\\": 24,
                                \\"timeUnit\\": 1
                            }}
                        }},
                        \\"type\\": \\"MsPortalFx.Composition.Configuration.ValueTypes.TimeRange\\"
                    }},
                    \\"filterLocale\\": {{
                        \\"value\\": \\"en-us\\"
                    }},
                    \\"filters\\": {{
                        \\"value\\": {{
                            \\"MsPortalFx_TimeRange\\": {{
                                \\"model\\": {{
                                    \\"format\\": \\"utc\\",
                                    \\"granularity\\": \\"auto\\",
                                    \\"relative\\": \\"24h\\"
                                }},
                                \\"displayCache\\": {{
                                    \\"name\\": \\"UTC Time\\",
                                    \\"value\\": \\"Past 24 hours\\"
                                }},
                                \\"filteredPartIds\\": [
                                    \\"StartboardPart-UnboundPart-ae44fef5-76b8-46b0-86f0-2b3f47bad1c7\\"
                                ]
                            }}
                        }}
                    }}
                }}
            }}
        }}
        \"\"\")
        ```

        It is recommended to follow the steps outlined
        [here](https://docs.microsoft.com/azure/azure-portal/azure-portal-dashboards-create-programmatically#fetch-the-json-representation-of-the-dashboard) to create a Dashboard in the Portal and extract the relevant JSON to use in this resource. From the extracted JSON, the contents of the `properties: {}` object can used. Variables can be injected as needed - see above example.

        ### Using a `template_file` data source or the `templatefile` function

        Since the contents of the dashboard JSON can be quite lengthy, use a template file to improve readability:

        `dash.tpl`:

        This is then referenced in the `.tf` file by using a `template_file` data source (terraform 0.11 or earlier), or the `templatefile` function (terraform 0.12+).

        `main.tf` (terraform 0.11 or earlier):

        ```python
        import pulumi
        import pulumi_azurerm as azurerm


        def not_implemented(msg):
            raise NotImplementedError(msg)

        dash_template = not_implemented("The template_file data resource is not yet supported.")
        #...
        my_board = azurerm.index.Dashboard("my-board",
            name=my-cool-dashboard,
            resource_group_name=example.name,
            location=example.location,
            tags={
                source: terraform,
            },
            dashboard_properties=dash_template.rendered)
        ```

        `main.tf` (terraform 0.12+)

        ## Import

        Dashboards can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:portal/portalDashboard:PortalDashboard my-board /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Portal/dashboards/00000000-0000-0000-0000-000000000000
        ```

        Note the URI in the above sample can be found using the Resource Explorer tool in the Azure Portal.


        :param str resource_name: The name of the resource.
        :param PortalDashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PortalDashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PortalDashboardArgs.__new__(PortalDashboardArgs)

            if dashboard_properties is None and not opts.urn:
                raise TypeError("Missing required property 'dashboard_properties'")
            __props__.__dict__["dashboard_properties"] = dashboard_properties
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="azure:portal/dashboard:Dashboard")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(PortalDashboard, __self__).__init__(
            'azure:portal/portalDashboard:PortalDashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'PortalDashboard':
        """
        Get an existing PortalDashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PortalDashboardState.__new__(_PortalDashboardState)

        __props__.__dict__["dashboard_properties"] = dashboard_properties
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        return PortalDashboard(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> pulumi.Output[_builtins.str]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['JobStepArgs', 'JobStep']

@pulumi.input_type
class JobStepArgs:
    def __init__(__self__, *,
                 job_id: pulumi.Input[_builtins.str],
                 job_step_index: pulumi.Input[_builtins.int],
                 job_target_group_id: pulumi.Input[_builtins.str],
                 sql_script: pulumi.Input[_builtins.str],
                 initial_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 job_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_target: Optional[pulumi.Input['JobStepOutputTargetArgs']] = None,
                 retry_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 retry_interval_backoff_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a JobStep resource.

        :param pulumi.Input[_builtins.str] job_id: The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[_builtins.int] job_step_index: The index at which to insert this Elastic Job Step into the Elastic Job.
               
               > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        :param pulumi.Input[_builtins.str] job_target_group_id: The ID of the Elastic Job Target Group.
        :param pulumi.Input[_builtins.str] sql_script: The T-SQL script to be executed by this Elastic Job Step.
               
               > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        :param pulumi.Input[_builtins.int] initial_retry_interval_seconds: The initial retry interval in seconds. Defaults to `1`.
        :param pulumi.Input[_builtins.str] job_credential_id: The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).
               
               !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        :param pulumi.Input[_builtins.int] maximum_retry_interval_seconds: The maximum retry interval in seconds. Defaults to `120`.
               
               > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input['JobStepOutputTargetArgs'] output_target: An `output_target` block as defined below.
        :param pulumi.Input[_builtins.int] retry_attempts: The number of retry attempts. Defaults to `10`.
        :param pulumi.Input[_builtins.float] retry_interval_backoff_multiplier: The multiplier for time between retries. Defaults to `2.0`.
        :param pulumi.Input[_builtins.int] timeout_seconds: The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        pulumi.set(__self__, "job_id", job_id)
        pulumi.set(__self__, "job_step_index", job_step_index)
        pulumi.set(__self__, "job_target_group_id", job_target_group_id)
        pulumi.set(__self__, "sql_script", sql_script)
        if initial_retry_interval_seconds is not None:
            pulumi.set(__self__, "initial_retry_interval_seconds", initial_retry_interval_seconds)
        if job_credential_id is not None:
            pulumi.set(__self__, "job_credential_id", job_credential_id)
        if maximum_retry_interval_seconds is not None:
            pulumi.set(__self__, "maximum_retry_interval_seconds", maximum_retry_interval_seconds)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_target is not None:
            pulumi.set(__self__, "output_target", output_target)
        if retry_attempts is not None:
            pulumi.set(__self__, "retry_attempts", retry_attempts)
        if retry_interval_backoff_multiplier is not None:
            pulumi.set(__self__, "retry_interval_backoff_multiplier", retry_interval_backoff_multiplier)
        if timeout_seconds is not None:
            pulumi.set(__self__, "timeout_seconds", timeout_seconds)

    @_builtins.property
    @pulumi.getter(name="jobId")
    def job_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "job_id")

    @job_id.setter
    def job_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "job_id", value)

    @_builtins.property
    @pulumi.getter(name="jobStepIndex")
    def job_step_index(self) -> pulumi.Input[_builtins.int]:
        """
        The index at which to insert this Elastic Job Step into the Elastic Job.

        > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        """
        return pulumi.get(self, "job_step_index")

    @job_step_index.setter
    def job_step_index(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "job_step_index", value)

    @_builtins.property
    @pulumi.getter(name="jobTargetGroupId")
    def job_target_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Elastic Job Target Group.
        """
        return pulumi.get(self, "job_target_group_id")

    @job_target_group_id.setter
    def job_target_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "job_target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="sqlScript")
    def sql_script(self) -> pulumi.Input[_builtins.str]:
        """
        The T-SQL script to be executed by this Elastic Job Step.

        > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        """
        return pulumi.get(self, "sql_script")

    @sql_script.setter
    def sql_script(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sql_script", value)

    @_builtins.property
    @pulumi.getter(name="initialRetryIntervalSeconds")
    def initial_retry_interval_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The initial retry interval in seconds. Defaults to `1`.
        """
        return pulumi.get(self, "initial_retry_interval_seconds")

    @initial_retry_interval_seconds.setter
    def initial_retry_interval_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "initial_retry_interval_seconds", value)

    @_builtins.property
    @pulumi.getter(name="jobCredentialId")
    def job_credential_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).

        !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        """
        return pulumi.get(self, "job_credential_id")

    @job_credential_id.setter
    def job_credential_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_credential_id", value)

    @_builtins.property
    @pulumi.getter(name="maximumRetryIntervalSeconds")
    def maximum_retry_interval_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum retry interval in seconds. Defaults to `120`.

        > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        """
        return pulumi.get(self, "maximum_retry_interval_seconds")

    @maximum_retry_interval_seconds.setter
    def maximum_retry_interval_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "maximum_retry_interval_seconds", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="outputTarget")
    def output_target(self) -> Optional[pulumi.Input['JobStepOutputTargetArgs']]:
        """
        An `output_target` block as defined below.
        """
        return pulumi.get(self, "output_target")

    @output_target.setter
    def output_target(self, value: Optional[pulumi.Input['JobStepOutputTargetArgs']]):
        pulumi.set(self, "output_target", value)

    @_builtins.property
    @pulumi.getter(name="retryAttempts")
    def retry_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of retry attempts. Defaults to `10`.
        """
        return pulumi.get(self, "retry_attempts")

    @retry_attempts.setter
    def retry_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retry_attempts", value)

    @_builtins.property
    @pulumi.getter(name="retryIntervalBackoffMultiplier")
    def retry_interval_backoff_multiplier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The multiplier for time between retries. Defaults to `2.0`.
        """
        return pulumi.get(self, "retry_interval_backoff_multiplier")

    @retry_interval_backoff_multiplier.setter
    def retry_interval_backoff_multiplier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "retry_interval_backoff_multiplier", value)

    @_builtins.property
    @pulumi.getter(name="timeoutSeconds")
    def timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        return pulumi.get(self, "timeout_seconds")

    @timeout_seconds.setter
    def timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout_seconds", value)


@pulumi.input_type
class _JobStepState:
    def __init__(__self__, *,
                 initial_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 job_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_step_index: Optional[pulumi.Input[_builtins.int]] = None,
                 job_target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_target: Optional[pulumi.Input['JobStepOutputTargetArgs']] = None,
                 retry_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 retry_interval_backoff_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 sql_script: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering JobStep resources.

        :param pulumi.Input[_builtins.int] initial_retry_interval_seconds: The initial retry interval in seconds. Defaults to `1`.
        :param pulumi.Input[_builtins.str] job_credential_id: The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).
               
               !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        :param pulumi.Input[_builtins.str] job_id: The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[_builtins.int] job_step_index: The index at which to insert this Elastic Job Step into the Elastic Job.
               
               > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        :param pulumi.Input[_builtins.str] job_target_group_id: The ID of the Elastic Job Target Group.
        :param pulumi.Input[_builtins.int] maximum_retry_interval_seconds: The maximum retry interval in seconds. Defaults to `120`.
               
               > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input['JobStepOutputTargetArgs'] output_target: An `output_target` block as defined below.
        :param pulumi.Input[_builtins.int] retry_attempts: The number of retry attempts. Defaults to `10`.
        :param pulumi.Input[_builtins.float] retry_interval_backoff_multiplier: The multiplier for time between retries. Defaults to `2.0`.
        :param pulumi.Input[_builtins.str] sql_script: The T-SQL script to be executed by this Elastic Job Step.
               
               > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        :param pulumi.Input[_builtins.int] timeout_seconds: The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        if initial_retry_interval_seconds is not None:
            pulumi.set(__self__, "initial_retry_interval_seconds", initial_retry_interval_seconds)
        if job_credential_id is not None:
            pulumi.set(__self__, "job_credential_id", job_credential_id)
        if job_id is not None:
            pulumi.set(__self__, "job_id", job_id)
        if job_step_index is not None:
            pulumi.set(__self__, "job_step_index", job_step_index)
        if job_target_group_id is not None:
            pulumi.set(__self__, "job_target_group_id", job_target_group_id)
        if maximum_retry_interval_seconds is not None:
            pulumi.set(__self__, "maximum_retry_interval_seconds", maximum_retry_interval_seconds)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_target is not None:
            pulumi.set(__self__, "output_target", output_target)
        if retry_attempts is not None:
            pulumi.set(__self__, "retry_attempts", retry_attempts)
        if retry_interval_backoff_multiplier is not None:
            pulumi.set(__self__, "retry_interval_backoff_multiplier", retry_interval_backoff_multiplier)
        if sql_script is not None:
            pulumi.set(__self__, "sql_script", sql_script)
        if timeout_seconds is not None:
            pulumi.set(__self__, "timeout_seconds", timeout_seconds)

    @_builtins.property
    @pulumi.getter(name="initialRetryIntervalSeconds")
    def initial_retry_interval_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The initial retry interval in seconds. Defaults to `1`.
        """
        return pulumi.get(self, "initial_retry_interval_seconds")

    @initial_retry_interval_seconds.setter
    def initial_retry_interval_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "initial_retry_interval_seconds", value)

    @_builtins.property
    @pulumi.getter(name="jobCredentialId")
    def job_credential_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).

        !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        """
        return pulumi.get(self, "job_credential_id")

    @job_credential_id.setter
    def job_credential_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_credential_id", value)

    @_builtins.property
    @pulumi.getter(name="jobId")
    def job_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "job_id")

    @job_id.setter
    def job_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_id", value)

    @_builtins.property
    @pulumi.getter(name="jobStepIndex")
    def job_step_index(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The index at which to insert this Elastic Job Step into the Elastic Job.

        > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        """
        return pulumi.get(self, "job_step_index")

    @job_step_index.setter
    def job_step_index(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "job_step_index", value)

    @_builtins.property
    @pulumi.getter(name="jobTargetGroupId")
    def job_target_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Elastic Job Target Group.
        """
        return pulumi.get(self, "job_target_group_id")

    @job_target_group_id.setter
    def job_target_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="maximumRetryIntervalSeconds")
    def maximum_retry_interval_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum retry interval in seconds. Defaults to `120`.

        > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        """
        return pulumi.get(self, "maximum_retry_interval_seconds")

    @maximum_retry_interval_seconds.setter
    def maximum_retry_interval_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "maximum_retry_interval_seconds", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="outputTarget")
    def output_target(self) -> Optional[pulumi.Input['JobStepOutputTargetArgs']]:
        """
        An `output_target` block as defined below.
        """
        return pulumi.get(self, "output_target")

    @output_target.setter
    def output_target(self, value: Optional[pulumi.Input['JobStepOutputTargetArgs']]):
        pulumi.set(self, "output_target", value)

    @_builtins.property
    @pulumi.getter(name="retryAttempts")
    def retry_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of retry attempts. Defaults to `10`.
        """
        return pulumi.get(self, "retry_attempts")

    @retry_attempts.setter
    def retry_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retry_attempts", value)

    @_builtins.property
    @pulumi.getter(name="retryIntervalBackoffMultiplier")
    def retry_interval_backoff_multiplier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The multiplier for time between retries. Defaults to `2.0`.
        """
        return pulumi.get(self, "retry_interval_backoff_multiplier")

    @retry_interval_backoff_multiplier.setter
    def retry_interval_backoff_multiplier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "retry_interval_backoff_multiplier", value)

    @_builtins.property
    @pulumi.getter(name="sqlScript")
    def sql_script(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The T-SQL script to be executed by this Elastic Job Step.

        > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        """
        return pulumi.get(self, "sql_script")

    @sql_script.setter
    def sql_script(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sql_script", value)

    @_builtins.property
    @pulumi.getter(name="timeoutSeconds")
    def timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        return pulumi.get(self, "timeout_seconds")

    @timeout_seconds.setter
    def timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout_seconds", value)


@pulumi.type_token("azure:mssql/jobStep:JobStep")
class JobStep(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 initial_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 job_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_step_index: Optional[pulumi.Input[_builtins.int]] = None,
                 job_target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_target: Optional[pulumi.Input[Union['JobStepOutputTargetArgs', 'JobStepOutputTargetArgsDict']]] = None,
                 retry_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 retry_interval_backoff_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 sql_script: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages an Elastic Job Step.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example",
            location="westeurope")
        example_server = azure.mssql.Server("example",
            name="example-server",
            location=example.location,
            resource_group_name=example.name,
            version="12.0",
            administrator_login="4dm1n157r470r",
            administrator_login_password="4-v3ry-53cr37-p455w0rd")
        example_database = azure.mssql.Database("example",
            name="example-db",
            server_id=example_server.id,
            collation="SQL_Latin1_General_CP1_CI_AS",
            sku_name="S1")
        example_job_agent = azure.mssql.JobAgent("example",
            name="example-job-agent",
            location=example.location,
            database_id=example_database.id)
        example_job_credential = azure.mssql.JobCredential("example",
            name="example-job-credential",
            job_agent_id=example_job_agent.id,
            username="exampleusername",
            password="examplepassword")
        example_job_target_group = azure.mssql.JobTargetGroup("example",
            name="example-target-group",
            job_agent_id=example_job_agent.id,
            job_targets=[{
                "server_name": example_server.name,
                "database_name": example_database.name,
                "job_credential_id": example_job_credential.id,
            }])
        example_job = azure.mssql.Job("example",
            name="example-job",
            job_agent_id=example_job_agent.id,
            description="example description")
        test = azure.mssql.JobStep("test",
            name="example-job-step",
            job_id=example_job.id,
            job_credential_id=example_job_credential.id,
            job_target_group_id=example_job_target_group.id,
            job_step_index=1,
            sql_script=\"\"\"IF NOT EXISTS (SELECT * FROM sys.objects WHERE [name] = N'Pets')
          CREATE TABLE Pets (
            Animal NVARCHAR(50),
            Name NVARCHAR(50),
          );
        \"\"\")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Sql` - 2023-08-01-preview

        ## Import

        Elastic Job Steps can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mssql/jobStep:JobStep example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Sql/servers/myserver1/jobAgents/myjobagent1/jobs/myjob1/steps/myjobstep1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] initial_retry_interval_seconds: The initial retry interval in seconds. Defaults to `1`.
        :param pulumi.Input[_builtins.str] job_credential_id: The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).
               
               !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        :param pulumi.Input[_builtins.str] job_id: The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[_builtins.int] job_step_index: The index at which to insert this Elastic Job Step into the Elastic Job.
               
               > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        :param pulumi.Input[_builtins.str] job_target_group_id: The ID of the Elastic Job Target Group.
        :param pulumi.Input[_builtins.int] maximum_retry_interval_seconds: The maximum retry interval in seconds. Defaults to `120`.
               
               > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[Union['JobStepOutputTargetArgs', 'JobStepOutputTargetArgsDict']] output_target: An `output_target` block as defined below.
        :param pulumi.Input[_builtins.int] retry_attempts: The number of retry attempts. Defaults to `10`.
        :param pulumi.Input[_builtins.float] retry_interval_backoff_multiplier: The multiplier for time between retries. Defaults to `2.0`.
        :param pulumi.Input[_builtins.str] sql_script: The T-SQL script to be executed by this Elastic Job Step.
               
               > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        :param pulumi.Input[_builtins.int] timeout_seconds: The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobStepArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Elastic Job Step.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example",
            location="westeurope")
        example_server = azure.mssql.Server("example",
            name="example-server",
            location=example.location,
            resource_group_name=example.name,
            version="12.0",
            administrator_login="4dm1n157r470r",
            administrator_login_password="4-v3ry-53cr37-p455w0rd")
        example_database = azure.mssql.Database("example",
            name="example-db",
            server_id=example_server.id,
            collation="SQL_Latin1_General_CP1_CI_AS",
            sku_name="S1")
        example_job_agent = azure.mssql.JobAgent("example",
            name="example-job-agent",
            location=example.location,
            database_id=example_database.id)
        example_job_credential = azure.mssql.JobCredential("example",
            name="example-job-credential",
            job_agent_id=example_job_agent.id,
            username="exampleusername",
            password="examplepassword")
        example_job_target_group = azure.mssql.JobTargetGroup("example",
            name="example-target-group",
            job_agent_id=example_job_agent.id,
            job_targets=[{
                "server_name": example_server.name,
                "database_name": example_database.name,
                "job_credential_id": example_job_credential.id,
            }])
        example_job = azure.mssql.Job("example",
            name="example-job",
            job_agent_id=example_job_agent.id,
            description="example description")
        test = azure.mssql.JobStep("test",
            name="example-job-step",
            job_id=example_job.id,
            job_credential_id=example_job_credential.id,
            job_target_group_id=example_job_target_group.id,
            job_step_index=1,
            sql_script=\"\"\"IF NOT EXISTS (SELECT * FROM sys.objects WHERE [name] = N'Pets')
          CREATE TABLE Pets (
            Animal NVARCHAR(50),
            Name NVARCHAR(50),
          );
        \"\"\")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Sql` - 2023-08-01-preview

        ## Import

        Elastic Job Steps can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mssql/jobStep:JobStep example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Sql/servers/myserver1/jobAgents/myjobagent1/jobs/myjob1/steps/myjobstep1
        ```


        :param str resource_name: The name of the resource.
        :param JobStepArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobStepArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 initial_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 job_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_id: Optional[pulumi.Input[_builtins.str]] = None,
                 job_step_index: Optional[pulumi.Input[_builtins.int]] = None,
                 job_target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_target: Optional[pulumi.Input[Union['JobStepOutputTargetArgs', 'JobStepOutputTargetArgsDict']]] = None,
                 retry_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 retry_interval_backoff_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 sql_script: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobStepArgs.__new__(JobStepArgs)

            __props__.__dict__["initial_retry_interval_seconds"] = initial_retry_interval_seconds
            __props__.__dict__["job_credential_id"] = job_credential_id
            if job_id is None and not opts.urn:
                raise TypeError("Missing required property 'job_id'")
            __props__.__dict__["job_id"] = job_id
            if job_step_index is None and not opts.urn:
                raise TypeError("Missing required property 'job_step_index'")
            __props__.__dict__["job_step_index"] = job_step_index
            if job_target_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'job_target_group_id'")
            __props__.__dict__["job_target_group_id"] = job_target_group_id
            __props__.__dict__["maximum_retry_interval_seconds"] = maximum_retry_interval_seconds
            __props__.__dict__["name"] = name
            __props__.__dict__["output_target"] = output_target
            __props__.__dict__["retry_attempts"] = retry_attempts
            __props__.__dict__["retry_interval_backoff_multiplier"] = retry_interval_backoff_multiplier
            if sql_script is None and not opts.urn:
                raise TypeError("Missing required property 'sql_script'")
            __props__.__dict__["sql_script"] = sql_script
            __props__.__dict__["timeout_seconds"] = timeout_seconds
        super(JobStep, __self__).__init__(
            'azure:mssql/jobStep:JobStep',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            initial_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            job_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
            job_id: Optional[pulumi.Input[_builtins.str]] = None,
            job_step_index: Optional[pulumi.Input[_builtins.int]] = None,
            job_target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            maximum_retry_interval_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            output_target: Optional[pulumi.Input[Union['JobStepOutputTargetArgs', 'JobStepOutputTargetArgsDict']]] = None,
            retry_attempts: Optional[pulumi.Input[_builtins.int]] = None,
            retry_interval_backoff_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
            sql_script: Optional[pulumi.Input[_builtins.str]] = None,
            timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None) -> 'JobStep':
        """
        Get an existing JobStep resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] initial_retry_interval_seconds: The initial retry interval in seconds. Defaults to `1`.
        :param pulumi.Input[_builtins.str] job_credential_id: The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).
               
               !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        :param pulumi.Input[_builtins.str] job_id: The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[_builtins.int] job_step_index: The index at which to insert this Elastic Job Step into the Elastic Job.
               
               > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        :param pulumi.Input[_builtins.str] job_target_group_id: The ID of the Elastic Job Target Group.
        :param pulumi.Input[_builtins.int] maximum_retry_interval_seconds: The maximum retry interval in seconds. Defaults to `120`.
               
               > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        :param pulumi.Input[Union['JobStepOutputTargetArgs', 'JobStepOutputTargetArgsDict']] output_target: An `output_target` block as defined below.
        :param pulumi.Input[_builtins.int] retry_attempts: The number of retry attempts. Defaults to `10`.
        :param pulumi.Input[_builtins.float] retry_interval_backoff_multiplier: The multiplier for time between retries. Defaults to `2.0`.
        :param pulumi.Input[_builtins.str] sql_script: The T-SQL script to be executed by this Elastic Job Step.
               
               > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        :param pulumi.Input[_builtins.int] timeout_seconds: The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobStepState.__new__(_JobStepState)

        __props__.__dict__["initial_retry_interval_seconds"] = initial_retry_interval_seconds
        __props__.__dict__["job_credential_id"] = job_credential_id
        __props__.__dict__["job_id"] = job_id
        __props__.__dict__["job_step_index"] = job_step_index
        __props__.__dict__["job_target_group_id"] = job_target_group_id
        __props__.__dict__["maximum_retry_interval_seconds"] = maximum_retry_interval_seconds
        __props__.__dict__["name"] = name
        __props__.__dict__["output_target"] = output_target
        __props__.__dict__["retry_attempts"] = retry_attempts
        __props__.__dict__["retry_interval_backoff_multiplier"] = retry_interval_backoff_multiplier
        __props__.__dict__["sql_script"] = sql_script
        __props__.__dict__["timeout_seconds"] = timeout_seconds
        return JobStep(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="initialRetryIntervalSeconds")
    def initial_retry_interval_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The initial retry interval in seconds. Defaults to `1`.
        """
        return pulumi.get(self, "initial_retry_interval_seconds")

    @_builtins.property
    @pulumi.getter(name="jobCredentialId")
    def job_credential_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the Elastic Job Credential to use when executing this Elastic Job Step. Omit this argument to run the step under the Job Agent's managed identity (user-assigned).

        !> **Note:** Once set, `job_credential_id` cannot be removed. Removing the credential will force a new resource to be created.
        """
        return pulumi.get(self, "job_credential_id")

    @_builtins.property
    @pulumi.getter(name="jobId")
    def job_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Elastic Job. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "job_id")

    @_builtins.property
    @pulumi.getter(name="jobStepIndex")
    def job_step_index(self) -> pulumi.Output[_builtins.int]:
        """
        The index at which to insert this Elastic Job Step into the Elastic Job.

        > **Note:** This value must be greater than or equal to 1 and less than or equal to the number of job steps in the Elastic Job.
        """
        return pulumi.get(self, "job_step_index")

    @_builtins.property
    @pulumi.getter(name="jobTargetGroupId")
    def job_target_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Elastic Job Target Group.
        """
        return pulumi.get(self, "job_target_group_id")

    @_builtins.property
    @pulumi.getter(name="maximumRetryIntervalSeconds")
    def maximum_retry_interval_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum retry interval in seconds. Defaults to `120`.

        > **Note:** `maximum_retry_interval_seconds` must be greater than `initial_retry_interval_seconds`.
        """
        return pulumi.get(self, "maximum_retry_interval_seconds")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Elastic Job Step. Changing this forces a new Elastic Job Step to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="outputTarget")
    def output_target(self) -> pulumi.Output[Optional['outputs.JobStepOutputTarget']]:
        """
        An `output_target` block as defined below.
        """
        return pulumi.get(self, "output_target")

    @_builtins.property
    @pulumi.getter(name="retryAttempts")
    def retry_attempts(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of retry attempts. Defaults to `10`.
        """
        return pulumi.get(self, "retry_attempts")

    @_builtins.property
    @pulumi.getter(name="retryIntervalBackoffMultiplier")
    def retry_interval_backoff_multiplier(self) -> pulumi.Output[Optional[_builtins.float]]:
        """
        The multiplier for time between retries. Defaults to `2.0`.
        """
        return pulumi.get(self, "retry_interval_backoff_multiplier")

    @_builtins.property
    @pulumi.getter(name="sqlScript")
    def sql_script(self) -> pulumi.Output[_builtins.str]:
        """
        The T-SQL script to be executed by this Elastic Job Step.

        > **Note:** While Azure places no restrictions on the script provided here, it is recommended to ensure the script is idempotent.
        """
        return pulumi.get(self, "sql_script")

    @_builtins.property
    @pulumi.getter(name="timeoutSeconds")
    def timeout_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The execution timeout in seconds for this Elastic Job Step. Defaults to `43200`.
        """
        return pulumi.get(self, "timeout_seconds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetResult',
    'AwaitableGetResult',
    'get',
    'get_output',
]

@pulumi.output_type
class GetResult:
    """
    A collection of values returned by get.
    """
    def __init__(__self__, customer_managed_keys=None, default_databases=None, high_availability_enabled=None, hostname=None, id=None, identities=None, location=None, name=None, public_network_access=None, resource_group_name=None, sku_name=None, tags=None):
        if customer_managed_keys and not isinstance(customer_managed_keys, list):
            raise TypeError("Expected argument 'customer_managed_keys' to be a list")
        pulumi.set(__self__, "customer_managed_keys", customer_managed_keys)
        if default_databases and not isinstance(default_databases, list):
            raise TypeError("Expected argument 'default_databases' to be a list")
        pulumi.set(__self__, "default_databases", default_databases)
        if high_availability_enabled and not isinstance(high_availability_enabled, bool):
            raise TypeError("Expected argument 'high_availability_enabled' to be a bool")
        pulumi.set(__self__, "high_availability_enabled", high_availability_enabled)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if public_network_access and not isinstance(public_network_access, str):
            raise TypeError("Expected argument 'public_network_access' to be a str")
        pulumi.set(__self__, "public_network_access", public_network_access)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku_name and not isinstance(sku_name, str):
            raise TypeError("Expected argument 'sku_name' to be a str")
        pulumi.set(__self__, "sku_name", sku_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeys")
    def customer_managed_keys(self) -> Sequence['outputs.GetCustomerManagedKeyResult']:
        """
        A `customer_managed_key` block as defined below.
        """
        return pulumi.get(self, "customer_managed_keys")

    @_builtins.property
    @pulumi.getter(name="defaultDatabases")
    def default_databases(self) -> Sequence['outputs.GetDefaultDatabaseResult']:
        """
        A `default_database` block as defined below.
        """
        return pulumi.get(self, "default_databases")

    @_builtins.property
    @pulumi.getter(name="highAvailabilityEnabled")
    def high_availability_enabled(self) -> _builtins.bool:
        """
        Whether high availability is enabled for the Managed Redis instance.
        """
        return pulumi.get(self, "high_availability_enabled")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> _builtins.str:
        """
        The DNS hostname of the Managed Redis instance.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetIdentityResult']:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identities")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the Managed Redis instance exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the Redis module.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> _builtins.str:
        """
        The public network access setting for the Managed Redis instance.
        """
        return pulumi.get(self, "public_network_access")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> _builtins.str:
        """
        The SKU name of the Managed Redis instance.
        """
        return pulumi.get(self, "sku_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags assigned to the Managed Redis instance.
        """
        return pulumi.get(self, "tags")


class AwaitableGetResult(GetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResult(
            customer_managed_keys=self.customer_managed_keys,
            default_databases=self.default_databases,
            high_availability_enabled=self.high_availability_enabled,
            hostname=self.hostname,
            id=self.id,
            identities=self.identities,
            location=self.location,
            name=self.name,
            public_network_access=self.public_network_access,
            resource_group_name=self.resource_group_name,
            sku_name=self.sku_name,
            tags=self.tags)


def get(name: Optional[_builtins.str] = None,
        resource_group_name: Optional[_builtins.str] = None,
        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResult:
    """
    Use this data source to access information about an existing Managed Redis instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.managedredis.get(name="example-managed-redis",
        resource_group_name="example-resources")
    pulumi.export("managedRedisHostname", example.hostname)
    pulumi.export("managedRedisPrimaryAccessKey", example.default_databases[0].primary_access_key)
    pulumi.export("managedRedisSecondaryAccessKey", example.default_databases[0].secondary_access_key)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Cache` - 2025-07-01


    :param _builtins.str name: The name of the Managed Redis instance.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Managed Redis instance exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:managedredis/get:get', __args__, opts=opts, typ=GetResult).value

    return AwaitableGetResult(
        customer_managed_keys=pulumi.get(__ret__, 'customer_managed_keys'),
        default_databases=pulumi.get(__ret__, 'default_databases'),
        high_availability_enabled=pulumi.get(__ret__, 'high_availability_enabled'),
        hostname=pulumi.get(__ret__, 'hostname'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        public_network_access=pulumi.get(__ret__, 'public_network_access'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        sku_name=pulumi.get(__ret__, 'sku_name'),
        tags=pulumi.get(__ret__, 'tags'))
def get_output(name: Optional[pulumi.Input[_builtins.str]] = None,
               resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetResult]:
    """
    Use this data source to access information about an existing Managed Redis instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.managedredis.get(name="example-managed-redis",
        resource_group_name="example-resources")
    pulumi.export("managedRedisHostname", example.hostname)
    pulumi.export("managedRedisPrimaryAccessKey", example.default_databases[0].primary_access_key)
    pulumi.export("managedRedisSecondaryAccessKey", example.default_databases[0].secondary_access_key)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Cache` - 2025-07-01


    :param _builtins.str name: The name of the Managed Redis instance.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Managed Redis instance exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:managedredis/get:get', __args__, opts=opts, typ=GetResult)
    return __ret__.apply(lambda __response__: GetResult(
        customer_managed_keys=pulumi.get(__response__, 'customer_managed_keys'),
        default_databases=pulumi.get(__response__, 'default_databases'),
        high_availability_enabled=pulumi.get(__response__, 'high_availability_enabled'),
        hostname=pulumi.get(__response__, 'hostname'),
        id=pulumi.get(__response__, 'id'),
        identities=pulumi.get(__response__, 'identities'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        public_network_access=pulumi.get(__response__, 'public_network_access'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        sku_name=pulumi.get(__response__, 'sku_name'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAccessPolicyAssignmentResult',
    'AwaitableGetAccessPolicyAssignmentResult',
    'get_access_policy_assignment',
    'get_access_policy_assignment_output',
]

@pulumi.output_type
class GetAccessPolicyAssignmentResult:
    """
    A collection of values returned by getAccessPolicyAssignment.
    """
    def __init__(__self__, id=None, managed_redis_name=None, object_id=None, resource_group_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if managed_redis_name and not isinstance(managed_redis_name, str):
            raise TypeError("Expected argument 'managed_redis_name' to be a str")
        pulumi.set(__self__, "managed_redis_name", managed_redis_name)
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        pulumi.set(__self__, "object_id", object_id)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="managedRedisName")
    def managed_redis_name(self) -> _builtins.str:
        return pulumi.get(self, "managed_redis_name")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> _builtins.str:
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")


class AwaitableGetAccessPolicyAssignmentResult(GetAccessPolicyAssignmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccessPolicyAssignmentResult(
            id=self.id,
            managed_redis_name=self.managed_redis_name,
            object_id=self.object_id,
            resource_group_name=self.resource_group_name)


def get_access_policy_assignment(managed_redis_name: Optional[_builtins.str] = None,
                                 object_id: Optional[_builtins.str] = None,
                                 resource_group_name: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccessPolicyAssignmentResult:
    """
    Use this data source to access information about an existing Managed Redis Access Policy Assignment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.managedredis.get_access_policy_assignment(object_id="00000000-0000-0000-0000-000000000000",
        managed_redis_name="example-managedredis",
        resource_group_name="example-resources")
    pulumi.export("objectId", example.object_id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Cache` - 2025-07-01


    :param _builtins.str managed_redis_name: The name of the Managed Redis instance.
    :param _builtins.str object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Managed Redis instance exists.
           
           > **Note:** This data source retrieves Access Policy Assignments from the `default` database of the Managed Redis instance.
    """
    __args__ = dict()
    __args__['managedRedisName'] = managed_redis_name
    __args__['objectId'] = object_id
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:managedredis/getAccessPolicyAssignment:getAccessPolicyAssignment', __args__, opts=opts, typ=GetAccessPolicyAssignmentResult).value

    return AwaitableGetAccessPolicyAssignmentResult(
        id=pulumi.get(__ret__, 'id'),
        managed_redis_name=pulumi.get(__ret__, 'managed_redis_name'),
        object_id=pulumi.get(__ret__, 'object_id'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'))
def get_access_policy_assignment_output(managed_redis_name: Optional[pulumi.Input[_builtins.str]] = None,
                                        object_id: Optional[pulumi.Input[_builtins.str]] = None,
                                        resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccessPolicyAssignmentResult]:
    """
    Use this data source to access information about an existing Managed Redis Access Policy Assignment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.managedredis.get_access_policy_assignment(object_id="00000000-0000-0000-0000-000000000000",
        managed_redis_name="example-managedredis",
        resource_group_name="example-resources")
    pulumi.export("objectId", example.object_id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Cache` - 2025-07-01


    :param _builtins.str managed_redis_name: The name of the Managed Redis instance.
    :param _builtins.str object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Managed Redis instance exists.
           
           > **Note:** This data source retrieves Access Policy Assignments from the `default` database of the Managed Redis instance.
    """
    __args__ = dict()
    __args__['managedRedisName'] = managed_redis_name
    __args__['objectId'] = object_id
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:managedredis/getAccessPolicyAssignment:getAccessPolicyAssignment', __args__, opts=opts, typ=GetAccessPolicyAssignmentResult)
    return __ret__.apply(lambda __response__: GetAccessPolicyAssignmentResult(
        id=pulumi.get(__response__, 'id'),
        managed_redis_name=pulumi.get(__response__, 'managed_redis_name'),
        object_id=pulumi.get(__response__, 'object_id'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetWorkspaceResult',
    'AwaitableGetWorkspaceResult',
    'get_workspace',
    'get_workspace_output',
]

@pulumi.output_type
class GetWorkspaceResult:
    """
    A collection of values returned by getWorkspace.
    """
    def __init__(__self__, api_management_id=None, display_name=None, id=None, name=None):
        if api_management_id and not isinstance(api_management_id, str):
            raise TypeError("Expected argument 'api_management_id' to be a str")
        pulumi.set(__self__, "api_management_id", api_management_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="apiManagementId")
    def api_management_id(self) -> _builtins.str:
        return pulumi.get(self, "api_management_id")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        The display name of the API Management Workspace.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")


class AwaitableGetWorkspaceResult(GetWorkspaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceResult(
            api_management_id=self.api_management_id,
            display_name=self.display_name,
            id=self.id,
            name=self.name)


def get_workspace(api_management_id: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceResult:
    """
    Use this data source to access information about an existing API Management Workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    example_service = azure.apimanagement.Service("example",
        name="example-apimanagement",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        publisher_name="pub1",
        publisher_email="pub1@email.com",
        sku_name="Premium_1")
    example = azure.apimanagement.get_workspace_output(name="existing",
        api_management_id=example_service.id)
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.ApiManagement` - 2024-05-01


    :param _builtins.str api_management_id: The ID of the API Management Workspace.
    :param _builtins.str name: The name of this API Management Workspace.
    """
    __args__ = dict()
    __args__['apiManagementId'] = api_management_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:apimanagement/getWorkspace:getWorkspace', __args__, opts=opts, typ=GetWorkspaceResult).value

    return AwaitableGetWorkspaceResult(
        api_management_id=pulumi.get(__ret__, 'api_management_id'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_workspace_output(api_management_id: Optional[pulumi.Input[_builtins.str]] = None,
                         name: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWorkspaceResult]:
    """
    Use this data source to access information about an existing API Management Workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    example_service = azure.apimanagement.Service("example",
        name="example-apimanagement",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        publisher_name="pub1",
        publisher_email="pub1@email.com",
        sku_name="Premium_1")
    example = azure.apimanagement.get_workspace_output(name="existing",
        api_management_id=example_service.id)
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.ApiManagement` - 2024-05-01


    :param _builtins.str api_management_id: The ID of the API Management Workspace.
    :param _builtins.str name: The name of this API Management Workspace.
    """
    __args__ = dict()
    __args__['apiManagementId'] = api_management_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:apimanagement/getWorkspace:getWorkspace', __args__, opts=opts, typ=GetWorkspaceResult)
    return __ret__.apply(lambda __response__: GetWorkspaceResult(
        api_management_id=pulumi.get(__response__, 'api_management_id'),
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GeoReplicationArgs', 'GeoReplication']

@pulumi.input_type
class GeoReplicationArgs:
    def __init__(__self__, *,
                 linked_managed_redis_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 managed_redis_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a GeoReplication resource.

        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] linked_managed_redis_ids: A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "linked_managed_redis_ids", linked_managed_redis_ids)
        pulumi.set(__self__, "managed_redis_id", managed_redis_id)

    @_builtins.property
    @pulumi.getter(name="linkedManagedRedisIds")
    def linked_managed_redis_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        """
        return pulumi.get(self, "linked_managed_redis_ids")

    @linked_managed_redis_ids.setter
    def linked_managed_redis_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "linked_managed_redis_ids", value)

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_redis_id")

    @managed_redis_id.setter
    def managed_redis_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "managed_redis_id", value)


@pulumi.input_type
class _GeoReplicationState:
    def __init__(__self__, *,
                 linked_managed_redis_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GeoReplication resources.

        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] linked_managed_redis_ids: A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        if linked_managed_redis_ids is not None:
            pulumi.set(__self__, "linked_managed_redis_ids", linked_managed_redis_ids)
        if managed_redis_id is not None:
            pulumi.set(__self__, "managed_redis_id", managed_redis_id)

    @_builtins.property
    @pulumi.getter(name="linkedManagedRedisIds")
    def linked_managed_redis_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        """
        return pulumi.get(self, "linked_managed_redis_ids")

    @linked_managed_redis_ids.setter
    def linked_managed_redis_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "linked_managed_redis_ids", value)

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_redis_id")

    @managed_redis_id.setter
    def managed_redis_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_redis_id", value)


@pulumi.type_token("azure:managedredis/geoReplication:GeoReplication")
class GeoReplication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 linked_managed_redis_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages Managed Redis Geo-Replication by linking and unlinking databases in a geo-replication group.

        > **Note:** This resource manages the geo-replication group membership for Managed Redis databases. All databases to be linked must have `geo_replication_group_name` provided with the same value. Linking will [discard cache data and cause temporary outage](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication#add-an-existing-instance-to-an-active-geo-replication-group).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-managedredis",
            location="West Europe")
        amr1 = azure.managedredis.ManagedRedis("amr1",
            name="example-managedredis-amr1",
            resource_group_name=example.name,
            location="West Europe",
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "example-geo-group",
            })
        amr2 = azure.managedredis.ManagedRedis("amr2",
            name="example-managedredis-amr2",
            resource_group_name=example.name,
            location="Central US",
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "example-geo-group",
            })
        example_geo_replication = azure.managedredis.GeoReplication("example",
            managed_redis_id=amr1.id,
            linked_managed_redis_ids=[amr2.id])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cache` - 2025-07-01

        ## Import

        Managed Redis Database Geo-Replication can be imported using the Managed Redis `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/geoReplication:GeoReplication example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/cluster1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] linked_managed_redis_ids: A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GeoReplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Managed Redis Geo-Replication by linking and unlinking databases in a geo-replication group.

        > **Note:** This resource manages the geo-replication group membership for Managed Redis databases. All databases to be linked must have `geo_replication_group_name` provided with the same value. Linking will [discard cache data and cause temporary outage](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication#add-an-existing-instance-to-an-active-geo-replication-group).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-managedredis",
            location="West Europe")
        amr1 = azure.managedredis.ManagedRedis("amr1",
            name="example-managedredis-amr1",
            resource_group_name=example.name,
            location="West Europe",
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "example-geo-group",
            })
        amr2 = azure.managedredis.ManagedRedis("amr2",
            name="example-managedredis-amr2",
            resource_group_name=example.name,
            location="Central US",
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "example-geo-group",
            })
        example_geo_replication = azure.managedredis.GeoReplication("example",
            managed_redis_id=amr1.id,
            linked_managed_redis_ids=[amr2.id])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cache` - 2025-07-01

        ## Import

        Managed Redis Database Geo-Replication can be imported using the Managed Redis `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/geoReplication:GeoReplication example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/cluster1
        ```


        :param str resource_name: The name of the resource.
        :param GeoReplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GeoReplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 linked_managed_redis_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GeoReplicationArgs.__new__(GeoReplicationArgs)

            if linked_managed_redis_ids is None and not opts.urn:
                raise TypeError("Missing required property 'linked_managed_redis_ids'")
            __props__.__dict__["linked_managed_redis_ids"] = linked_managed_redis_ids
            if managed_redis_id is None and not opts.urn:
                raise TypeError("Missing required property 'managed_redis_id'")
            __props__.__dict__["managed_redis_id"] = managed_redis_id
        super(GeoReplication, __self__).__init__(
            'azure:managedredis/geoReplication:GeoReplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            linked_managed_redis_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'GeoReplication':
        """
        Get an existing GeoReplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] linked_managed_redis_ids: A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GeoReplicationState.__new__(_GeoReplicationState)

        __props__.__dict__["linked_managed_redis_ids"] = linked_managed_redis_ids
        __props__.__dict__["managed_redis_id"] = managed_redis_id
        return GeoReplication(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="linkedManagedRedisIds")
    def linked_managed_redis_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A set of other Managed Redis IDs to link together in the geo-replication group. The ID of this Managed Redis is always included by default and does not need to be provided here. Can contain up to 4 Managed Redis IDs, making up a group of 5 in total. All Managed Redis must have the same `geo_replication_group_name` configured. Once linked, the geo-replication state of all Managed Redis will be updated.
        """
        return pulumi.get(self, "linked_managed_redis_ids")

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Managed Redis through which geo-replication group will be managed. Linking is reciprocal, if A is linked to B, both A and B will have the same linking state. There is no need to have duplicate `managedredis.GeoReplication` resources for each. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "managed_redis_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDatabaseSystemVersionsResult',
    'AwaitableGetDatabaseSystemVersionsResult',
    'get_database_system_versions',
    'get_database_system_versions_output',
]

@pulumi.output_type
class GetDatabaseSystemVersionsResult:
    """
    A collection of values returned by getDatabaseSystemVersions.
    """
    def __init__(__self__, database_software_image_supported=None, database_system_shape=None, id=None, location=None, shape_family=None, storage_management=None, upgrade_supported=None, versions=None):
        if database_software_image_supported and not isinstance(database_software_image_supported, bool):
            raise TypeError("Expected argument 'database_software_image_supported' to be a bool")
        pulumi.set(__self__, "database_software_image_supported", database_software_image_supported)
        if database_system_shape and not isinstance(database_system_shape, str):
            raise TypeError("Expected argument 'database_system_shape' to be a str")
        pulumi.set(__self__, "database_system_shape", database_system_shape)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if shape_family and not isinstance(shape_family, str):
            raise TypeError("Expected argument 'shape_family' to be a str")
        pulumi.set(__self__, "shape_family", shape_family)
        if storage_management and not isinstance(storage_management, str):
            raise TypeError("Expected argument 'storage_management' to be a str")
        pulumi.set(__self__, "storage_management", storage_management)
        if upgrade_supported and not isinstance(upgrade_supported, bool):
            raise TypeError("Expected argument 'upgrade_supported' to be a bool")
        pulumi.set(__self__, "upgrade_supported", upgrade_supported)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter(name="databaseSoftwareImageSupported")
    def database_software_image_supported(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "database_software_image_supported")

    @_builtins.property
    @pulumi.getter(name="databaseSystemShape")
    def database_system_shape(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "database_system_shape")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter(name="shapeFamily")
    def shape_family(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "shape_family")

    @_builtins.property
    @pulumi.getter(name="storageManagement")
    def storage_management(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "storage_management")

    @_builtins.property
    @pulumi.getter(name="upgradeSupported")
    def upgrade_supported(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "upgrade_supported")

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetDatabaseSystemVersionsVersionResult']:
        """
        A `versions` block as defined below.
        """
        return pulumi.get(self, "versions")


class AwaitableGetDatabaseSystemVersionsResult(GetDatabaseSystemVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseSystemVersionsResult(
            database_software_image_supported=self.database_software_image_supported,
            database_system_shape=self.database_system_shape,
            id=self.id,
            location=self.location,
            shape_family=self.shape_family,
            storage_management=self.storage_management,
            upgrade_supported=self.upgrade_supported,
            versions=self.versions)


def get_database_system_versions(database_software_image_supported: Optional[_builtins.bool] = None,
                                 database_system_shape: Optional[_builtins.str] = None,
                                 location: Optional[_builtins.str] = None,
                                 shape_family: Optional[_builtins.str] = None,
                                 storage_management: Optional[_builtins.str] = None,
                                 upgrade_supported: Optional[_builtins.bool] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseSystemVersionsResult:
    """
    Use this data source to access information about existing Oracle Database Systems Versions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_database_system_versions(location="eastus")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.bool database_software_image_supported: Whether to filter the results to the set of Oracle Database versions that are supported for the database software images.
    :param _builtins.str database_system_shape: If provided, filters the results to the set of database versions which are supported for the given shape. The only possible value is `VM.Standard.x86`.
    :param _builtins.str location: The Azure Region to query for the Oracle Database Systems Versions.
    :param _builtins.str shape_family: If provided, filters the results to the set of database versions which are supported for the given shape family. Possible values are `EXADATA`, `EXADB_XS`, `SINGLENODE` and `VIRTUALMACHINE`.
    :param _builtins.str storage_management: The database system storage management option. Used to list database versions available for that storage manager. The only possible value is `LVM`.
    :param _builtins.bool upgrade_supported: Whether to filter the results to the set of database versions which are supported for upgrade.
    """
    __args__ = dict()
    __args__['databaseSoftwareImageSupported'] = database_software_image_supported
    __args__['databaseSystemShape'] = database_system_shape
    __args__['location'] = location
    __args__['shapeFamily'] = shape_family
    __args__['storageManagement'] = storage_management
    __args__['upgradeSupported'] = upgrade_supported
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:oracle/getDatabaseSystemVersions:getDatabaseSystemVersions', __args__, opts=opts, typ=GetDatabaseSystemVersionsResult).value

    return AwaitableGetDatabaseSystemVersionsResult(
        database_software_image_supported=pulumi.get(__ret__, 'database_software_image_supported'),
        database_system_shape=pulumi.get(__ret__, 'database_system_shape'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        shape_family=pulumi.get(__ret__, 'shape_family'),
        storage_management=pulumi.get(__ret__, 'storage_management'),
        upgrade_supported=pulumi.get(__ret__, 'upgrade_supported'),
        versions=pulumi.get(__ret__, 'versions'))
def get_database_system_versions_output(database_software_image_supported: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        database_system_shape: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        location: Optional[pulumi.Input[_builtins.str]] = None,
                                        shape_family: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        storage_management: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        upgrade_supported: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseSystemVersionsResult]:
    """
    Use this data source to access information about existing Oracle Database Systems Versions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_database_system_versions(location="eastus")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.bool database_software_image_supported: Whether to filter the results to the set of Oracle Database versions that are supported for the database software images.
    :param _builtins.str database_system_shape: If provided, filters the results to the set of database versions which are supported for the given shape. The only possible value is `VM.Standard.x86`.
    :param _builtins.str location: The Azure Region to query for the Oracle Database Systems Versions.
    :param _builtins.str shape_family: If provided, filters the results to the set of database versions which are supported for the given shape family. Possible values are `EXADATA`, `EXADB_XS`, `SINGLENODE` and `VIRTUALMACHINE`.
    :param _builtins.str storage_management: The database system storage management option. Used to list database versions available for that storage manager. The only possible value is `LVM`.
    :param _builtins.bool upgrade_supported: Whether to filter the results to the set of database versions which are supported for upgrade.
    """
    __args__ = dict()
    __args__['databaseSoftwareImageSupported'] = database_software_image_supported
    __args__['databaseSystemShape'] = database_system_shape
    __args__['location'] = location
    __args__['shapeFamily'] = shape_family
    __args__['storageManagement'] = storage_management
    __args__['upgradeSupported'] = upgrade_supported
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:oracle/getDatabaseSystemVersions:getDatabaseSystemVersions', __args__, opts=opts, typ=GetDatabaseSystemVersionsResult)
    return __ret__.apply(lambda __response__: GetDatabaseSystemVersionsResult(
        database_software_image_supported=pulumi.get(__response__, 'database_software_image_supported'),
        database_system_shape=pulumi.get(__response__, 'database_system_shape'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        shape_family=pulumi.get(__response__, 'shape_family'),
        storage_management=pulumi.get(__response__, 'storage_management'),
        upgrade_supported=pulumi.get(__response__, 'upgrade_supported'),
        versions=pulumi.get(__response__, 'versions')))
